@@ -1,8 +1,9 @@
 from abc import ABCMeta, abstractmethod
 from typing import Dict, Union
+from uuid import UUID
 
 from nidhoggr.core.response import StatusResponse, TextureStatusResponse, ErrorResponse
-from nidhoggr.core.texture import TextureUploadRequest, TextureRequest, TextureResponse
+from nidhoggr.core.texture import TextureUploadRequest, TextureRequest, SimpleTextureResponse
 from nidhoggr.core.user import User
 
 
@@ -10,7 +11,7 @@ class BaseTextureRepo(metaclass=ABCMeta):
     variant: str
 
     @abstractmethod
-    def get(self, *, request: TextureRequest) -> Union[ErrorResponse, TextureResponse]:
+    def get(self, *, request: TextureRequest) -> Union[ErrorResponse, SimpleTextureResponse]:
         pass
 
     @abstractmethod
@@ -31,7 +32,7 @@ class BaseUserRepo(metaclass=ABCMeta):
     )
 
     @abstractmethod
-    def get_user(self, **kw: Dict[str, str]) -> Union[ErrorResponse, User]:
+    def get_user(self, **kw: Dict[str, Union[str, UUID]]) -> Union[ErrorResponse, User]:
         pass
 
     @abstractmethod
