@@ -1,9 +1,12 @@
+from base64 import b64encode
 from enum import Enum
 from typing import Optional, Dict, List
 
 from pydantic import UUID4
 from pydantic.main import BaseModel
 
+from nidhoggr.core.user import UserProperty
+
 TextureMeta = Optional[Dict[str, str]]
 
 
@@ -39,9 +42,25 @@ class TextureUploadRequest(BaseModel):
         allow_mutation = False
 
 
-class TextureResponse(BaseModel):
+class SimpleTextureResponse(BaseModel):
     textures: Dict[TextureType, TextureItem]
 
     class Config:
         allow_mutation = False
         use_enum_values = True
+
+
+class ComplexTextureResponse(SimpleTextureResponse):
+    timestamp: int
+    profileId: UUID4
+    profileName: str
+
+    class Config:
+        allow_mutation = False
+        use_enum_values = True
+
+    def pack(self) -> UserProperty:
+        return UserProperty(
+            name="textures",
+            value=b64encode(self.json().encode('ascii')).decode('ascii')
+        )
