@@ -1,5 +1,6 @@
 from typing import Optional, List
 
+from pydantic import UUID4
 from pydantic.main import BaseModel
 
 
@@ -21,11 +22,11 @@ class UserProperty(BaseModel):
 
 
 class User(BaseModel):
-    uuid: str
+    uuid: UUID4
     login: str
     email: str
-    access: Optional[str] = None
-    client: Optional[str] = None
+    access: Optional[UUID4] = None
+    client: Optional[UUID4] = None
     server: Optional[str] = None
     properties: List[UserProperty] = []
     synthetic: bool = False
@@ -35,11 +36,11 @@ class User(BaseModel):
 
 
 class UserRequest(BaseModel):
-    uuid: Optional[str] = None
+    uuid: Optional[UUID4] = None
     login: Optional[str] = None
     email: Optional[str] = None
-    access: Optional[str] = None
-    client: Optional[str] = None
+    access: Optional[UUID4] = None
+    client: Optional[UUID4] = None
     server: Optional[str] = None
 
     class Config:
@@ -47,7 +48,7 @@ class UserRequest(BaseModel):
 
 
 class PasswordRequest(BaseModel):
-    uuid: str
+    uuid: UUID4
     password: str
 
     class Config:
