@@ -1,4 +1,5 @@
 from typing import Dict, Union
+from uuid import UUID
 
 from nidhoggr.core.repository import BaseUserRepo
 from nidhoggr.core.response import StatusResponse, ErrorResponse
@@ -8,7 +9,7 @@ from nidhoggr.requests.core import RequestsRepo
 
 class RequestsUserRepo(BaseUserRepo, RequestsRepo):
 
-    def get_user(self, **kwargs: Dict[str, str]) -> Union[ErrorResponse, User]:
+    def get_user(self, **kwargs: Dict[str, Union[str, UUID]]) -> Union[ErrorResponse, User]:
         payload = UserRequest(**kwargs)
         return self.fetch(endpoint='/user/get/', payload=payload, clazz=User)
 
